// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KHOLIDAYS_VERSION_H
#define KHOLIDAYS_VERSION_H

#define KHOLIDAYS_VERSION_STRING "6.12.0"
#define KHOLIDAYS_VERSION_MAJOR 6
#define KHOLIDAYS_VERSION_MINOR 12
#define KHOLIDAYS_VERSION_PATCH 0
#define KHOLIDAYS_VERSION ((6<<16)|(12<<8)|(0))

#endif
